@@ -2,7 +2,7 @@
 pyapi-gitlab tests
 """
 
-import unittest
+import unittest2 as unittest
 import gitlab
 import os
 import time
